@@ -1,11 +1,13 @@
 #pragma once
 
 #include <cstdio>
+#include <memory>
+#include <string>
 
-#include "MaeParserConfig.hpp"
 #include "Buffer.hpp"
 #include "MaeBlock.hpp"
 #include "MaeParser.hpp"
+#include "MaeParserConfig.hpp"
 
 namespace schrodinger
 {
@@ -15,26 +17,22 @@ namespace mae
 class EXPORT_MAEPARSER Reader
 {
   private:
-    MaeParser* m_mae_parser;
+    std::shared_ptr<MaeParser> m_mae_parser;
 
   public:
-    Reader(FILE* file, size_t buffer_size = BufferLoader::DEFAULT_SIZE)
-        : m_mae_parser(nullptr)
-    {
-        m_mae_parser = new MaeParser(file, buffer_size);
-    }
+    Reader() = delete;
+    Reader(FILE* file, size_t buffer_size = BufferLoader::DEFAULT_SIZE);
 
-    Reader(std::istream& stream,
-           size_t buffer_size = BufferLoader::DEFAULT_SIZE)
-        : m_mae_parser(nullptr)
-    {
-        m_mae_parser = new MaeParser(stream, buffer_size);
-    }
+    Reader(const std::shared_ptr<std::istream>& stream,
+           size_t buffer_size = BufferLoader::DEFAULT_SIZE);
+
+    Reader(const std::string& fname,
+           size_t buffer_size = BufferLoader::DEFAULT_SIZE);
 
     // Should be made private if we conclude there's no need for the
     // DirectParser. The only current purpose of allowing construction from a
     // MaeParser is to allow direct/buffered behavior difference.
-    Reader(MaeParser* mae_parser) : m_mae_parser(mae_parser) {}
+    Reader(std::shared_ptr<MaeParser> mae_parser);
 
     std::shared_ptr<Block> next(const std::string& outer_block_name);
 };
